<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:xlink="http://www.w3.org/1999/xlink"	
	xmlns:rep="http://safe.epcc.ed.ac.uk/report"
	xmlns:acc="http://safe.epcc.ed.ac.uk/restrict"
	xmlns:par="http://safe.epcc.ed.ac.uk/parameter"
	xmlns:per="http://safe.epcc.ed.ac.uk/period"
	xmlns:fil="http://safe.epcc.ed.ac.uk/filter"
	xmlns:tab="http://safe.epcc.ed.ac.uk/table"
	xmlns:cha="http://safe.epcc.ed.ac.uk/chart"
	xmlns:ato="http://safe.epcc.ed.ac.uk/atom"
	xmlns:svg="http://www.w3.org/2000/svg">

   	<!--  Let stylesheet set the line breaks -->
	<xsl:strip-space elements="rep:table Table table rep:tr Tr tr"/>
	<!-- generate PDF skeleton on root element -->
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="page"
					page-height="29.7cm" page-width="21cm" margin-top="1cm"
					margin-bottom="2cm" margin-left="1.5cm" margin-right="1.5cm">
					<fo:region-body margin-top="3cm" />
					<fo:region-before extent="3cm" />

					<fo:region-after extent="1.5cm" />
				</fo:simple-page-master>

				<fo:page-sequence-master master-name="all">
					<fo:repeatable-page-master-alternatives>

						<fo:conditional-page-master-reference
							master-reference="page" page-position="first" />
						<fo:conditional-page-master-reference
							master-reference="page" page-position="rest" />
					</fo:repeatable-page-master-alternatives>
				</fo:page-sequence-master>
			</fo:layout-master-set>

			<fo:page-sequence master-reference="all">
				<fo:flow flow-name="xsl-region-body">
					<fo:block>
						<xsl:apply-templates />
					</fo:block>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<!-- Convert title to a XSL-FO heading -->
	<xsl:template match="rep:Report/rep:Title|rep:Report/Title">
		<fo:block font-size="20pt" text-align="center" color="black">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>

	<!-- Convert headings to XSL-FO headings -->
	<xsl:template match="rep:Report/rep:Heading">
		<fo:block font-size="18pt" color="black" font-weight="bold"
			space-before.optimum="20pt">
			<xsl:apply-templates select="text()" />
		</fo:block>
	</xsl:template>

	<!-- Convert paragraphs -->
	<xsl:template match="rep:Text|P|p|Para|Text">
		<fo:block space-before.optimum="10pt" font-size="12pt">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>

	<xsl:template match="rep:Nodata|NoData">
	   <fo:block space-before.optimum="10pt" font-size="12pt" font-weight="bold" text-align="center">
	    This plot contained no data
	    </fo:block>
	</xsl:template>
	<!-- Convert sections to XSL-FO headings -->
	<xsl:template match="rep:Section/rep:Title|rep:Section/Title">
		<fo:block font-size="16pt" color="black" font-weight="bold"
			space-before.optimum="20pt">
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>

	<!-- Convert sub-sections to XSL-FO headings -->
	<xsl:template match="rep:SubSection/rep:Title|rep:SubSection/Title">
		<fo:block font-size="14pt" color="black" font-weight="bold"
			space-before.optimum="15pt">
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>

	

	<!-- Convert tables to fo:tables -->
	<xsl:template match="rep:table|Table|table">
		<fo:table table-layout="fixed" width="100%">
			<xsl:apply-templates select="rep:tr/rep:th|Tr/Th|tr/th" mode="header" />
			<fo:table-header font-size="10pt" font-family="sans-serif">
				<xsl:apply-templates select="rep:tr[rep:th]|Tr[Th]|tr[th]" />
			</fo:table-header>
			<fo:table-body font-size="8pt" font-family="sans-serif"
				hyphenate="true">
				<xsl:apply-templates select="rep:tr[rep:td]|Tr[Td]|tr[td]" />
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template match="rep:th|Th|th" mode="header">
		<fo:table-column column-width="proportional-column-width(1)" />
	</xsl:template>
	<xsl:template match="rep:tr|Tr|tr">
		<fo:table-row>
			<xsl:apply-templates select="rep:th|rep:td|Th|Td|th|td" />
		</fo:table-row>
	</xsl:template>

	<xsl:template match="rep:th|Th|th">
		<fo:table-cell border-color="black" border-style="solid"
			border-width="0.2mm">
			<fo:block font-weight="bold" text-align="center">
				<xsl:apply-templates />
			</fo:block>
		</fo:table-cell>
	</xsl:template>

	<xsl:template match="rep:td|Td|td">
		<fo:table-cell border-color="black" border-style="solid"
			border-width="0.2mm">
			<fo:block text-align="right">
				<xsl:apply-templates />
			</fo:block>
		</fo:table-cell>
	</xsl:template>
	
	<!-- images mapped onto external graphics -->
	<xsl:template match="rep:Figure|Figure|figure">
		<fo:block space-before.optimum="10pt" text-align="center">
			<fo:table table-layout="fixed" width="100%">
				<fo:table-column column-width="proportional-column-width(1)"/>
				<fo:table-column column-width="12cm"/>
				<fo:table-column column-width="proportional-column-width(1)"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell column-number="2">
							<fo:block text-align="center">
								<fo:instream-foreign-object
									content-width="12cm" scaling="scale-to-fit">
									<xsl:copy-of select="svg:*" />
								</fo:instream-foreign-object>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell column-number="2">
							<fo:block font-size="10pt" space-before.optimum="0pt"
								text-align="left">
								<xsl:apply-templates select="rep:Caption|Caption|caption"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>
</xsl:stylesheet>

       
