-- Initial MySQL Configuration for GridSAFE --
-- v1.00

-- Create the database 
DROP DATABASE IF EXISTS gridsafe;
CREATE DATABASE gridsafe;

-- Create a MySQL user 'gridsafe' with password 'gridsafe'
-- A cautious person might consider changing the password
GRANT ALL PRIVILEGES ON gridsafe.* TO 'gridsafe'@'localhost' IDENTIFIED BY '%GRIDSAFE_DB_PASS%';

USE gridsafe;


--
-- Table structure for table `Machine`
--

DROP TABLE IF EXISTS `Machine`;

CREATE TABLE `Machine` (
  `MachineRecordID` int(11) NOT NULL auto_increment,
  `Name` varchar(32) NOT NULL default '',
  `Description` varchar(255) default NULL,
  `Table` varchar(64) default NULL,
  PRIMARY KEY  (`MachineRecordID`),
  UNIQUE KEY `name_key` (`Name`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

--
-- Data for table `Machine`
--

LOCK TABLES `Machine` WRITE;
UNLOCK TABLES;

--
-- Table structure for table `Person`
--

DROP TABLE IF EXISTS `Person`;
CREATE TABLE `Person` (
  `PersonRecordID` int(11) NOT NULL auto_increment,
  `Email` varchar(128) default NULL,
  `WebName` varchar(128) default NULL,
  PRIMARY KEY  (`PersonRecordID`),
  UNIQUE KEY `webname_key` (`WebName`)
) ;

--
-- Dumping data for table `Person`
--

LOCK TABLES `Person` WRITE;
/*!40000 ALTER TABLE `Person` DISABLE KEYS */;
INSERT INTO `Person` VALUES (1,NULL,'/gridsafe');
INSERT INTO `Person` VALUES (2,NULL,'/C=UK/ST=Hants/O=University of Southampton/OU=IGE-Project/CN=dogbert.omii.ac.uk');
/*!40000 ALTER TABLE `Person` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `Properties`
--

DROP TABLE IF EXISTS `Properties`;
CREATE TABLE `Properties` (
  `PrimaryRecordID` int(11) NOT NULL auto_increment,
  `Name` varchar(255) NOT NULL default '',
  `Value` varchar(255) NOT NULL default '',
  PRIMARY KEY  (`PrimaryRecordID`),
  UNIQUE KEY `name_key` (`Name`)
) ;

--
-- Data for table `Properties`
--

LOCK TABLES `Properties` WRITE;
UNLOCK TABLES;

--
-- Table structure for table `TextFileOverlay`
--

DROP TABLE IF EXISTS `TextFileOverlay`;
CREATE TABLE `TextFileOverlay` (
  `TextFileOverlayRecordID` int(11) NOT NULL auto_increment,
  `Group` varchar(255) NOT NULL default '',
  `Name` varchar(255) NOT NULL default '',
  `Text` mediumtext,
  PRIMARY KEY  (`TextFileOverlayRecordID`),
  UNIQUE KEY `find_key` (`Group`,`Name`)
) ;

--
-- Data for table `TextFileOverlay`
--

LOCK TABLES `TextFileOverlay` WRITE;
/*!40000 ALTER TABLE `TextFileOverlay` DISABLE KEYS */;
/*!40000 ALTER TABLE `TextFileOverlay` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `role_table`
--

DROP TABLE IF EXISTS `role_table`;
CREATE TABLE `role_table` (
  `PrimaryRecordID` int(11) NOT NULL auto_increment,
  `PersonID` int(11) NOT NULL default '0',
  `Role` varchar(32) NOT NULL default '',
  PRIMARY KEY  (`PrimaryRecordID`)
) ;

--
-- Dumping data for table `role_table`
--

LOCK TABLES `role_table` WRITE;
/*!40000 ALTER TABLE `role_table` DISABLE KEYS */;
INSERT INTO `role_table` VALUES (1,1,'Admin');
INSERT INTO `role_table` VALUES (2,2,'RupiPublish');
/*!40000 ALTER TABLE `role_table` ENABLE KEYS */;
UNLOCK TABLES;

-- Create UsageRecord table

CREATE TABLE `OGFURecord` (
  `OGFURecordId` int(11) NOT NULL auto_increment,
  `Charge` double default NULL,
  `ConsumableResource` float default NULL,
  `CpuDuration` bigint(20) default NULL,
  `Disk` int(11) default NULL,
  `EndTime` bigint(20) default NULL,
  `FQAN` varchar(255) default NULL,
  `GlobalJobId` varchar(255) default NULL,
  `GlobalUsername` varchar(255) default NULL,
  `Group` varchar(255) default NULL,
  `Host` varchar(255) default NULL,
  `JobName` varchar(255) default NULL,
  `LocalJobId` varchar(255) default NULL,
  `LocalUserId` varchar(255) default NULL,
  `MachineName` varchar(255) default NULL,
  `Memory` int(11) default NULL,
  `Network` int(11) default NULL,
  `Nodecount` int(11) default NULL,
  `PhaseResource` float default NULL,
  `ProcessId` varchar(255) default NULL,
  `Processors` int(11) default NULL,
  `ProjectName` varchar(255) default NULL,
  `Queue` varchar(32) default NULL,
  `RecordIdentity` varchar(256) default NULL,
  `createTime` bigint(20) default NULL,
  `recordId` varchar(255) default NULL,
  `Resource` varchar(255) default NULL,
  `ServiceLevel` varchar(255) default NULL,
  `StartTime` bigint(20) default NULL,
  `Status` varchar(255) default NULL,
  `SubmitHost` varchar(255) default NULL,
  `Swap` int(11) default NULL,
  `TimeDuration` bigint(20) default NULL,
  `TimeInstant` bigint(20) default NULL,
  `VolumeResource` float default NULL,
  `vo_group` varchar(255) default NULL,
  `vo_role` varchar(255) default NULL,
  `WallDuration` bigint(20) default NULL,
  `Text` TEXT default NULL,
  PRIMARY KEY  (`OGFURecordId`),
  KEY `duplicate_key` (`recordId`),
  KEY `end_time_key` (`EndTime`),
  KEY `start_time_key` (`StartTime`)
);

CREATE TABLE `ReportTemplate` (
  `ReportTemplateRecordID` int(11) NOT NULL auto_increment,
  `ReportName` varchar(64) NOT NULL default '',
  `TemplateName` varchar(128) NOT NULL default '',
  `ReportDescription` varchar(255) NOT NULL default '',
  `SortPriority` int(11) NOT NULL default '50',
  PRIMARY KEY  (`ReportTemplateRecordID`)
);
--
-- Dumping data for table `ReportTemplate`
--
INSERT INTO `ReportTemplate` VALUES (2,'TimeChart','TimeChart.xml','Time Chart',1),(3,'AggregateTimeChart','AggregateTimeChart.xml','Aggregate Time Chart',2),(4,'BarTimeChart','BarTimeChart.xml','Bar Time Chart',3),(5,'PieTimeChart','PieTimeChart.xml','Pie Time Chart',4),(6,'ServiceUsage','ServiceUsage.xml','Service Usage',5);
